#ifndef NT2_INCLUDE_FUNCTIONS_ACSCD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ACSCD_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/acscd.hpp>

#endif
